#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-IY2FT9BJZZIH6xNAOCirvp
key:                  coinbase-pro-0.9.3.2-IY2FT9BJZZIH6xNAOCirvp
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  5b3a1c3fe83b527d6e76ffc48d9792ed
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-IY2FT9BJZZIH6xNAOCirvp
depends:
    HsOpenSSL-0.11.7.10-CrfWqmplugxAwNDBXq9cCX
    aeson-2.2.2.0-3pjCpj5XtaHAHmzSwnt06z
    aeson-casing-0.2.0.0-1C9MEwYsLJoHgP0EWRykaE
    async-2.2.6-ClOW2oFWjQTDZxVKjsrmlu base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-8l0vgGVIKjy7Czr8tYHBZQ exceptions-0.10.7
    http-api-data-0.6.1-5rw4rYexF9LBK7T8HJM8P8
    http-client-0.7.19-JFk9tUfcyF3FnWNRzLmEjW
    http-client-tls-0.3.6.4-Dj2m0zumhuN7HSttI52C5a
    http-streams-0.8.9.9-AlE3LsxjnY9GZAotlQaNlt
    http-types-0.12.4-FjxwRmZWhoR3wzry1r4T66
    io-streams-1.5.2.2-DdHkI6wA1Ps4iMBoNS8F6Z
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-9nB9sbnLDjyBVIWLW7TDGb
    servant-0.20.3.0-D09I80t1F0W66xVLAg1Zhs
    servant-client-0.20.3.0-4MJETQjDOgVHqN3JBjE1oX
    servant-client-core-0.20.3.0-Ays6d3snXApKm6Ijb8dKic
    tasty-1.5.4-GkivOVRJs7F6rF5OuEyJnC
    tasty-hunit-0.10.2-IyGMLJQ0P1qA3GfBVc1Boi text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unagi-streams-0.2.7-FNky2uofEaqJ8AkmaOn3ZI
    unordered-containers-0.2.21-5Z67IC6H036CG8YRUzTmvt
    uuid-1.3.16.1-IOSNwAVvUqVFQ2c2QwOTYP
    vector-0.13.2.0-9mJIQr0XJi1KVzSJMcMTkU
    websockets-0.12.7.3-GNsVyAa2Dfl6b1lwmIHr8c
    wuss-2.0.1.7-4opjNSByUry84EcqO4iUoG

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

